.. _index:

===================
Kotti documentation
===================

Kotti is a user-friendly, light-weight and extensible web content management system, based on Pyramid and SQLAlchemy.

First steps
-----------

.. toctree::
    :maxdepth: 1

    first_steps/overview
    first_steps/installation
    first_steps/tut-1
    first_steps/tut-2

Topics
------

.. toctree::
    :maxdepth: 1

    developing/developer-manual
    developing/security
    developing/configuration
    developing/testing
    developing/translations
    developing/deployment

-   Advanced topics

    .. toctree::
        :maxdepth: 1

        developing/as-a-library
        developing/close-for-anonymous
        developing/default-views
        developing/frontpage-different-template
        developing/images
        developing/static-resource-management

API
---

.. toctree::
    :maxdepth: 1

    API documentation <api/index>

Changes
-------

.. toctree::
    :maxdepth: 1

    Complete list of changes since Kotti 0.2a1 <changes>
